@@ -1,8 +1,7 @@
+from nba_stats_tracking.models.boxscore.boxscore import BoxscoreResults
 from nba_stats_tracking.models.boxscore.request import BoxscoreRequestParameters
-from nba_stats_tracking.models.boxscore.boxscore import BoxscoreItem, BoxscoreResults
 
 __all__ = [
     "BoxscoreRequestParameters",
-    "BoxscoreItem",
     "BoxscoreResults",
 ]
